﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;

namespace RadEventToCommandExamples.PrismCommands
{
    public static class RowEditEndedCommand
    {
        private static readonly DependencyProperty RowEditEndedCommandBehaviorProperty
            = DependencyProperty.RegisterAttached(
            "RowEditEndedCommandBehavior",
            typeof(RowEditEndedCommandBehavior),
            typeof(RowEditEndedCommand),
            null);

        public static readonly DependencyProperty CommandProperty
            = DependencyProperty.RegisterAttached(
            "Command",
            typeof(ICommand),
            typeof(RowEditEndedCommand),
            new PropertyMetadata(OnSetCommandCallback));

        public static readonly DependencyProperty CommandParameterProperty
            = DependencyProperty.RegisterAttached(
           "CommandParameter",
           typeof(object),
           typeof(RowEditEndedCommand),
           new PropertyMetadata(OnSetCommandParameterCallback));

        public static ICommand GetCommand(RadGridView gridView)
        {
            return gridView.GetValue(CommandProperty) as ICommand;
        }

        public static void SetCommand(RadGridView gridView, object parameter)
        {
            gridView.SetValue(CommandProperty, parameter);
        }

        public static void SetCommandParameter(RadGridView gridView, object parameter)
        {
            gridView.SetValue(CommandParameterProperty, parameter);
        }

        public static object GetCommandParameter(RadGridView gridView)
        {
            return gridView.GetValue(CommandParameterProperty);
        }

        private static void OnSetCommandCallback
            (DependencyObject dependencyObject, DependencyPropertyChangedEventArgs e)
        {
            RadGridView gridView = dependencyObject as RadGridView;
            if (gridView != null)
            {
                RowEditEndedCommandBehavior behavior = GetOrCreateBehavior(gridView);
                behavior.Command = e.NewValue as ICommand;
            }
        }

        private static void OnSetCommandParameterCallback
            (DependencyObject dependencyObject, DependencyPropertyChangedEventArgs e)
        {
            RadGridView gridView = dependencyObject as RadGridView;
            if (gridView != null)
            {
                RowEditEndedCommandBehavior behavior = GetOrCreateBehavior(gridView);
                behavior.CommandParameter = e.NewValue;
            }
        }

        private static RowEditEndedCommandBehavior GetOrCreateBehavior(RadGridView gridView)
        {
            RowEditEndedCommandBehavior behavior =
                gridView.GetValue(RowEditEndedCommandBehaviorProperty) as RowEditEndedCommandBehavior;
            if (behavior == null)
            {
                behavior = new RowEditEndedCommandBehavior(gridView);
                gridView.SetValue(RowEditEndedCommandBehaviorProperty, behavior);
            }
            return behavior;
        }
    }
}